@@ -49,7 +49,7 @@
 #'
 #' @examples
 #' \dontrun{
-#' input_pattern <- spatstat::rpoispp(lambda = function(x, y) {100 * exp(-3 * x)}, nsim = 1)
+#' input_pattern <- spatstat.core::rpoispp(lambda = function(x, y) {100 * exp(-3 * x)}, nsim = 1)
 #'
 #' pattern_recon <- reconstruct_pattern_hetero(input_pattern, n_random = 19, max_runs = 1000)
 #' }
@@ -123,9 +123,9 @@ reconstruct_pattern_hetero <- function(pattern,
   }
 
   # unmark pattern
-  if (spatstat::is.marked(pattern)) {
+  if (spatstat.geom::is.marked(pattern)) {
 
-    pattern <- spatstat::unmark(pattern)
+    pattern <- spatstat.geom::unmark(pattern)
 
     if (verbose) {
       warning("Unmarked provided input pattern. For marked pattern, see reconstruct_pattern_marks().",
@@ -135,15 +135,15 @@ reconstruct_pattern_hetero <- function(pattern,
 
   # calculate r
   r <- seq(from = 0,
-           to = spatstat::rmax.rule(W = pattern$window,
-                                    lambda = spatstat::intensity.ppp(pattern)),
+           to = spatstat.core::rmax.rule(W = pattern$window,
+                                         lambda = spatstat.geom::intensity.ppp(pattern)),
            length.out = r_length)
 
   # estimate lambda(x,y)
-  lambda <- spatstat::density.ppp(pattern)
+  lambda <- spatstat.core::density.ppp(pattern)
 
   # create starting pattern
-  simulated <- spatstat::rpoint(n = pattern$n,
+  simulated <- spatstat.core::rpoint(n = pattern$n,
                                 f = lambda,
                                 win = pattern$window)
 
@@ -151,9 +151,9 @@ reconstruct_pattern_hetero <- function(pattern,
   # fast computation of summary functions
   if (comp_fast) {
 
-    gest_observed <- spatstat::Gest(pattern, correction = "none", r = r)
+    gest_observed <- spatstat.core::Gest(pattern, correction = "none", r = r)
 
-    gest_simulated <- spatstat::Gest(simulated, correction = "none", r = r)
+    gest_simulated <- spatstat.core::Gest(simulated, correction = "none", r = r)
 
     pcf_observed <- shar::estimate_pcf_fast(pattern,
                                             correction = "none",
@@ -171,15 +171,15 @@ reconstruct_pattern_hetero <- function(pattern,
   # normal computation of summary functions
   else {
 
-    gest_observed <- spatstat::Gest(X = pattern, correction = "han", r = r)
+    gest_observed <- spatstat.core::Gest(X = pattern, correction = "han", r = r)
 
-    gest_simulated <- spatstat::Gest(X = simulated, correction = "han", r = r)
+    gest_simulated <- spatstat.core::Gest(X = simulated, correction = "han", r = r)
 
-    pcf_observed <- spatstat::pcf.ppp(X = pattern, correction = "best",
+    pcf_observed <- spatstat.core::pcf.ppp(X = pattern, correction = "best",
                                       divisor = "d",
                                       r = r)
 
-    pcf_simulated <- spatstat::pcf.ppp(X = simulated, correction = "best",
+    pcf_simulated <- spatstat.core::pcf.ppp(X = simulated, correction = "best",
                                        divisor = "d",
                                        r = r)
   }
@@ -210,7 +210,7 @@ reconstruct_pattern_hetero <- function(pattern,
                                n = max_runs, replace = TRUE)
 
     # create random new points
-    rp_coords <- spatstat::rpoint(n = max_runs,
+    rp_coords <- spatstat.core::rpoint(n = max_runs,
                                   f = lambda,
                                   win = pattern$window)
 
@@ -242,7 +242,7 @@ reconstruct_pattern_hetero <- function(pattern,
       # calculate summary functions after relocation
       if (comp_fast) {
 
-        gest_relocated <- spatstat::Gest(relocated, correction = "none", r = r)
+        gest_relocated <- spatstat.core::Gest(relocated, correction = "none", r = r)
 
         pcf_relocated <- shar::estimate_pcf_fast(relocated,
                                                  correction = "none",
@@ -253,9 +253,9 @@ reconstruct_pattern_hetero <- function(pattern,
 
       else {
 
-        gest_relocated <- spatstat::Gest(X = relocated, correction = "han", r = r)
+        gest_relocated <- spatstat.core::Gest(X = relocated, correction = "han", r = r)
 
-        pcf_relocated <- spatstat::pcf.ppp(X = relocated, correction = "best",
+        pcf_relocated <- spatstat.core::pcf.ppp(X = relocated, correction = "best",
                                            divisor = "d",
                                            r = r)
       }
@@ -286,6 +286,8 @@ reconstruct_pattern_hetero <- function(pattern,
                          type = "l", col = "black",
                          xlab = "r", ylab = "g(r)")
 
+          graphics::abline(h = 1, lty = 2, col = "grey")
+
           graphics::lines(x = pcf_relocated[[1]], y = pcf_relocated[[3]], col = "red")
 
           graphics::legend("topright",
