@@ -1,4 +1,4 @@
-testthat::context("Translate raster")
+testthat::context("test-translate_raster")
 
 # n_random <- (raster::nrow(landscape) + 1) * (raster::ncol(landscape) + 1)  - 4
 
@@ -34,22 +34,22 @@ landscape_classified_wrong <- shar::classify_habitats(landscape_wrong, classes =
 
 testthat::test_that("Output is a long as n_random for translate_raster", {
 
-  testthat::expect_length(landscape_random,
-                          n = 2598)
+  testthat::expect_length(landscape_random$randomized,
+                          n = 2597)
 })
 
 testthat::test_that("Output includes randomizations and original pattern for translate_raster", {
 
-  testthat::expect_named(landscape_random,
-                         expected = c(paste0("randomized_", 1:2597), "observed"))
+  testthat::expect_named(landscape_random$randomized,
+                         expected = paste0("randomized_", 1:2597))
 
-  testthat::expect_equal(landscape_random[[2598]],
+  testthat::expect_equal(landscape_random$observed,
                          expected = landscape_classified)
 })
 
 testthat::test_that("Input raster can not be returned for translate_raster", {
 
-  check <- vapply(X = landscape_random_steps, FUN = function(x) {
+  check <- vapply(X = landscape_random_steps$randomized, FUN = function(x) {
 
     landscape_diff <- landscape_classified - x
 
@@ -61,7 +61,7 @@ testthat::test_that("Input raster can not be returned for translate_raster", {
 
 testthat::test_that("Providing steps is working for translate_raster", {
 
-  testthat::expect_length(landscape_random_steps,
+  testthat::expect_length(landscape_random_steps$randomized,
                           n = 9)
 })
 
